Module der_mach_to

Module der_mach_to 

Derivatives of relations as a function of Mach number

Functions

der_mach_to_a_ac
der_mach_to_f_mcpt0
der_mach_to_mcpt0_ap
der_mach_to_mcpt0_ap0
der_mach_to_p0_p
der_mach_to_rho0_rho
der_mach_to_t0_t
Total temperature ratio for given mach number and specific heat ratio
der_mach_to_v_cpt0