Module mach_to

Module mach_to 

Collection of functions for isentropic compressible flow.

Functions

mach_to_a_ac
Critical area ratio for given Mach number and specific heat ratio
mach_to_f_mcpt
Impulse function for given Mach number and specific heat ratio
mach_to_mach_angle
Mach angle in radians for a given mach number.
mach_to_mcpt0_ap
Static normalised mass flow for given Mach number and specific heat ratio
mach_to_mcpt0_ap0
Normalised mass flow for given Mach number and specific heat ratio
mach_to_p0_p
Total pressure ratio for given mach number and specific heat ratio
mach_to_p_p0
Total pressure ratio for given mach number and specific heat ratio
mach_to_pm_angle
Prandtl-Meyer angle in radians for a given mach number and specific heat ratio.
mach_to_rho0_rho
Stagnation density ratio for given mach number and specific heat ratio
mach_to_rho_rho0
Stagnation density ratio for given mach number and specific heat ratio
mach_to_t0_t
Total temperature ratio for given mach number and specific heat ratio
mach_to_t_t0
Total temperature ratio for given mach number and specific heat ratio
mach_to_v_cpt0
Normalised velocity for given Mach number and specific heat ratio